# Endringslogg

## v0.2.0
- Konfigurering av programmet gjøres nå grafisk, og det er lagt til en knapp på hovedvinduet som gir en tilgang til å endre på ting etter førstegangsbruk.
- Kundeskjermen har nå blitt responsiv dersom man endrer størrelsen på vinduet.

## v0.1.8
- Bruker nå `xdg-open` for å åpne pdf-filer, slik at man ikke trenger å konfigurere pdf-leseren man bruker
- For testing lager programmet nå en configfil i working directory i stedet for å bruke systemfilen.

## v0.1.7
- Rettet en avrundingsfeil som kunne oppstå ved enkelte rabattsatser

## v0.1.6
- Pakker nå med fonter i applikasjonen, slik at pdfer ser like ut, uansett operativsystem.
- Fikset en bug med avrunding (Takk til @martinvl)


## v0.1.5
- Lagt til endringslogg
- Kortet ned tid på animasjon mellom bilder
